@@ -1,20 +1,20 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2010 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2010-2012 -- leonerd@leonerd.org.uk
 
 package Net::Async::IRC::Protocol;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use base qw( IO::Async::Protocol::LineStream );
 
 use Carp;
 
-use Net::Async::IRC::Message;
+use Protocol::IRC::Message;
 
 use Encode qw( find_encoding );
 use Time::HiRes qw( time );
@@ -253,7 +253,7 @@ sub on_read_line
    my $self = shift;
    my ( $line ) = @_;
 
-   my $message = Net::Async::IRC::Message->new_from_line( $line );
+   my $message = Protocol::IRC::Message->new_from_line( $line );
 
    my $pingtimer = $self->{pingtimer};
 
@@ -284,7 +284,7 @@ sub on_read_line
 
 =head2 $irc->send_message( $message )
 
-Sends a message to the peer from the given C<Net::Async::IRC::Message>
+Sends a message to the peer from the given C<Protocol::IRC::Message>
 object.
 
 =head2 $irc->send_message( $command, $prefix, @args )
@@ -308,14 +308,14 @@ sub send_message
       my ( $command, $prefix, @args ) = @_;
 
       if( my $encoder = $self->{encoder} ) {
-         my $argnames = Net::Async::IRC::Message->arg_names( $command );
+         my $argnames = Protocol::IRC::Message->arg_names( $command );
 
          if( defined( my $i = $argnames->{text} ) ) {
             $args[$i] = $encoder->encode( $args[$i] ) if defined $args[$i];
          }
       }
 
-      $message = Net::Async::IRC::Message->new( $command, $prefix, @args );
+      $message = Protocol::IRC::Message->new( $command, $prefix, @args );
    }
 
    $self->write_line( $message->stream_to_line );
@@ -416,7 +416,8 @@ sub _set_isupport
       if( $name eq "PREFIX" ) {
          my $prefix = $value;
 
-         my ( $prefix_modes, $prefix_flags ) = $prefix =~ m/^\(([a-z]+)\)(.+)$/;
+         my ( $prefix_modes, $prefix_flags ) = $prefix =~ m/^\(([a-z]+)\)(.+)$/i
+            or warn( "Unable to parse PREFIX=$value" ), next;
 
          $self->{isupport}{prefix_modes} = $prefix_modes;
          $self->{isupport}{prefix_flags} = $prefix_flags;
@@ -698,7 +699,7 @@ value.
 
 =item prefix_host => STRING
 
-Values split from the message prefix; see the C<Net::Async::IRC::Message>
+Values split from the message prefix; see the C<Protocol::IRC::Message>
 C<prefix_split> method.
 
 =item prefix_name => STRING
